@@ -1,12 +1,17 @@
+import os
+import sys
 class Grade:#This module will get the grades of the students according to their marks
 
     def __init__(self,marksSecured,marksOutOf=None):
         if marksOutOf is None:
-            quit("Total marks part is missing, should be after marks scored followed by comma. Say (200, 500)")
+            exit("Total marks part is missing, should be after marks scored followed by comma. Say (200, 500)")
+            os._exit(1)
         elif marksOutOf <0 or marksSecured<0:
-            quit("This module works with postive values only!")
+            exit("This module works with postive values only!")
+            os._exit(1)
         elif marksOutOf==0:
-            quit("How can total marks be as 0?")
+            exit("How can total marks be 0?")
+            os._exit(1)
         else:
             self.marksSecured=marksSecured
             self.marksOutOf=marksOutOf
@@ -15,9 +20,17 @@ class Grade:#This module will get the grades of the students according to their
 
     def getGrade(self):#this will calculate grade
         total=str(self.total)
-        if self.marksOutOf==''  or self.marksSecured > self.marksOutOf or self.marksSecured<0:
-            self.grade=0
-            return "Can't find grades with this data!"   
+        if self.marksOutOf=='': 
+            self.grade=99
+            return "How can you expect any result from this module with invalid total marks value!"   
+        
+        elif self.marksSecured > self.marksOutOf:
+            self.grade=98
+            return "How can you expect any result from this module when you provide more marks scored than total marks!"   
+        
+        elif self.marksSecured<0:            
+            self.grade=97
+            return "Please provide positive integer values only!"   
             
         elif self.total>89 and self.total<101:
             self.grade=1
@@ -45,8 +58,14 @@ class Grade:#This module will get the grades of the students according to their
     def remarks(self):
         #this will ouput the result according to the grade secured
                     
-        if self.grade==0:
-            print("Please provide proper values!")
+        if self.grade==99:
+            print("Please provide proper values to get remarks!")
+            
+        elif self.grade==98:
+            print("How can any one get more marks than total marks?")
+            
+        elif self.grade==97:
+            print("Sorry! This module is not designed to work with negative integers.")
         
         elif self.grade==1:
             print('It is great saying that hard work pays-off! You did it, congratulations!')
